"""
@generated by codestare-proto-plus.  Do not edit manually!

Note:
    __init__.py files for packages are autogenerated, and import all messages from submodules to keep import names consistent with the directory structure of the ``.proto`` source files.
"""
from .buttonEventType_pb_plus import (
    ButtonEventType,
)

from .color_pb_plus import (
    Color,
)

from .handGestureType_pb_plus import (
    HandGestureType,
)

from .image_pb_plus import (
    Image2D,
    Image2DList,
)

from .keyEvent_pb_plus import (
    KeyEvent,
)

from .lists_pb_plus import (
    BoolList,
    DoubleList,
    FloatList,
    Int32List,
    StringList,
)

from .matrix3x2_pb_plus import (
    Matrix3x2,
)

from .matrix4x4_pb_plus import (
    Matrix4x4,
)

from .mouseEvent_pb_plus import (
    MouseEvent,
)

from .myoEvent_pb_plus import (
    MyoEvent,
)

from .object2d_pb_plus import (
    Object2D,
    Object2DList,
)

from .object3d_pb_plus import (
    Object3D,
    Object3DList,
)

from .pose2d_pb_plus import (
    Pose2D,
)

from .pose3d_pb_plus import (
    Pose3D,
)

from .quaternion_pb_plus import (
    Quaternion,
    QuaternionList,
)

from .touchEvent_pb_plus import (
    TouchEvent,
    TouchEventList,
)

from .vector2_pb_plus import (
    Vector2,
    Vector2List,
)

from .vector3_pb_plus import (
    Vector3,
    Vector3List,
)

from .vector4_pb_plus import (
    Vector4,
    Vector4List,
)

from .vector8_pb_plus import (
    Vector8,
    Vector8List,
)


__all__ = (
    "BoolList",
    "ButtonEventType",
    "Color",
    "DoubleList",
    "FloatList",
    "HandGestureType",
    "Image2D",
    "Image2DList",
    "Int32List",
    "KeyEvent",
    "Matrix3x2",
    "Matrix4x4",
    "MouseEvent",
    "MyoEvent",
    "Object2D",
    "Object2DList",
    "Object3D",
    "Object3DList",
    "Pose2D",
    "Pose3D",
    "Quaternion",
    "QuaternionList",
    "StringList",
    "TouchEvent",
    "TouchEventList",
    "Vector2",
    "Vector2List",
    "Vector3",
    "Vector3List",
    "Vector4",
    "Vector4List",
    "Vector8",
    "Vector8List",
)


"""
@generated by codestare-proto-plus.  Do not edit manually!
"""
from proto import (
    Field,
    RepeatedField,
    STRING,
    module,
)

from proto.message import (
    Message,
)


__protobuf__ = module(
    package="ubii.proto.v1.devices",
    marshal="ubii.proto.v1",
    manifest={
        "TopicMux",
        "TopicMuxList",
    }
)


class TopicMux(Message):
    """
    Attributes:
        id (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.STRING`
        name (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.STRING`
        data_type (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.STRING`
        topic_selector (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.STRING`
        identity_match_pattern (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.STRING`
    """

    id = Field(
        STRING,
        number=1,
    )
    name = Field(
        STRING,
        number=2,
    )
    data_type = Field(
        STRING,
        number=3,
    )
    topic_selector = Field(
        STRING,
        number=4,
    )
    identity_match_pattern = Field(
        STRING,
        number=5,
    )


class TopicMuxList(Message):
    """
    Attributes:
        elements (proto.fields.RepeatedField): :obj:`~proto.fields.RepeatedField` of type
            :obj:`~.TopicMux`
    """

    elements = RepeatedField(
        TopicMux,
        number=1,
    )




"""
This meta package is used to import the protobuf message types.

Note:
    Only import from :mod:`ubii.proto`, not directly from the module set in :obj:`ubii.proto.__proto_module__`
"""

try:
    from importlib.metadata import distribution, version, PackageNotFoundError
except ImportError:  # for Python<3.8
    from importlib_metadata import distribution, version, PackageNotFoundError

import proto
from more_itertools import take, pad_none

from .v1 import (
    Client,
    ClientList,
    ButtonEventType,
    HandGestureType,
    Color,
    Image2D,
    Image2DList,
    KeyEvent,
    StringList,
    DoubleList,
    FloatList,
    BoolList,
    Int32List,
    Matrix3x2,
    Matrix4x4,
    MouseEvent,
    MyoEvent,
    Object2D,
    Object2DList,
    Object3D,
    Object3DList,
    Pose2D,
    Pose3D,
    Quaternion,
    QuaternionList,
    TouchEvent,
    TouchEventList,
    Vector2,
    Vector2List,
    Vector3,
    Vector3List,
    Vector4,
    Vector4List,
    Vector8,
    Vector8List,
    Component,
    ComponentList,
    Device,
    DeviceList,
    TopicDemux,
    TopicDemuxList,
    TopicMux,
    TopicMuxList,
    Error,
    ErrorList,
    Success,
    SuccessList,
    LockstepProcessingRequest,
    LockstepProcessingReply,
    ProcessingMode,
    ModuleIO,
    ProcessingModule,
    ProcessingModuleList,
    Constants,
    Server,
    Service,
    ServiceList,
    ServiceReply,
    ServiceRequest,
    TopicSubscription,
    SessionStatus,
    TopicInputMapping,
    TopicInputMappingList,
    TopicOutputMapping,
    TopicOutputMappingList,
    IOMapping,
    IOMappingList,
    Session,
    SessionList,
    Timestamp,
    TopicData,
    TopicDataRecord,
    TopicDataRecordList,
)

__proto_types__ = (
    "Client",
    "ClientList",
    "ButtonEventType",
    "HandGestureType",
    "Color",
    "Image2D",
    "Image2DList",
    "KeyEvent",
    "StringList",
    "DoubleList",
    "FloatList",
    "BoolList",
    "Int32List",
    "Matrix3x2",
    "Matrix4x4",
    "MouseEvent",
    "MyoEvent",
    "Object2D",
    "Object2DList",
    "Object3D",
    "Object3DList",
    "Pose2D",
    "Pose3D",
    "Quaternion",
    "QuaternionList",
    "TouchEvent",
    "TouchEventList",
    "Vector2",
    "Vector2List",
    "Vector3",
    "Vector3List",
    "Vector4",
    "Vector4List",
    "Vector8",
    "Vector8List",
    "Component",
    "ComponentList",
    "Device",
    "DeviceList",
    "TopicDemux",
    "TopicDemuxList",
    "TopicMux",
    "TopicMuxList",
    "Error",
    "ErrorList",
    "Success",
    "SuccessList",
    "LockstepProcessingRequest",
    "LockstepProcessingReply",
    "ProcessingMode",
    "ModuleIO",
    "ProcessingModule",
    "ProcessingModuleList",
    "Constants",
    "Server",
    "Service",
    "ServiceList",
    "ServiceReply",
    "ServiceRequest",
    "TopicSubscription",
    "SessionStatus",
    "TopicInputMapping",
    "TopicInputMappingList",
    "TopicOutputMapping",
    "TopicOutputMappingList",
    "IOMapping",
    "IOMappingList",
    "Session",
    "SessionList",
    "Timestamp",
    "TopicData",
    "TopicDataRecord",
    "TopicDataRecordList",
)

from .util import (
    ProtoMeta,
    ProtoEncoder,
)

__all__ = __proto_types__ + (
    'ProtoMeta',
    'ProtoEncoder',
    '__protobuf__',
    '__proto_module__',
    '__proto_package__'
)

_pkg_name = 'ubii-message-formats'
try:
    __version__ = version(_pkg_name)
    info = take(2, pad_none(distribution(_pkg_name)
                            .read_text('proto_package.txt')
                            .split('='))
                )
except PackageNotFoundError as e:
    raise PackageNotFoundError(f"{_pkg_name} is not found, did the package name change?") from e
del _pkg_name

__proto_module__ = info[0]
"""
The actual import path of the module that contains the autogenerated protobuf code. Users are supposed to import from
:mod:`ubii.proto` instead.
"""
__proto_package__ = info[1]
"""
The name used for the :class:`~proto.marshal.Marshal`.
"""
__protobuf__ = proto.module(
    package=__proto_package__ or __proto_module__,
    manifest=set(__proto_types__)
)
"""
Used by :doc:`plus:index` to aggregate defined protobuf message in the same descriptor
pool. You need to import this attribute in every module that extends an existing protobuf wrapper class using
:class:`ubii.proto.ProtoMeta`. In essence this is a named tuple with attributes ``package`` and ``marshal`` containing 
the name for the :class:`~proto.marshal.Marshal` used by this package and ``manifest`` containing a set of all
:class:`~proto.message.Message` available from this module.

Example:
    You may want to create a extension to the wrapper around :class:`ubii.proto.Error`
    to be able to raise the error as an exception::

        from functools import lru_cache
        from proto.marshal import Marshal
        from proto.marshal.rules.message import MessageRule

        import ubii.proto as ub
        __protobuf__ = ub.__protobuf__


        class BaseError(ub.Error, Exception, metaclass=ub.ProtoMeta):
            @classmethod
            @lru_cache
            def rule(cls):
                return MessageRule(ub.Error.pb(), cls)

            @property
            def args(self):
                return self.title, self.message, self.stack

        class SessionRuntimeStopServiceError(BaseError):
            pass

        class OtherError(BaseError):
            pass

        class ErrorRule(MessageRule):
            def to_python(self, value, *, absent: bool | None = None):
                title = value.title or ''
                rule = None

                if title.startswith('SessionRuntimeStopService'):
                    rule = SessionRuntimeStopServiceError.rule()
                elif title.startswith('Other'):
                    rule = OtherError.rule()
                else:
                    rule = BaseError.rule()

                return rule.to_python(value, absent=absent)

            def to_proto(self, value):
                return super().to_proto(value)

        # register the new marshal rule to automatically convert errors

        Marshal(name=__protobuf__.marshal).register(ub.Error.pb(), ErrorRule(ub.Error.pb(), BaseError))
"""

if __proto_package__ is None:
    raise ImportError("package is not set in proto_package.txt from ubii-message-formats."
                      " This is unexpected, make sure you compiled the ubii-message-formats with a recent"
                      " version of the proto-plus-plugin. For more info resort to the documentation of the"
                      " proto-plus plugin")



"""
@generated by codestare-proto-plus.  Do not edit manually!

Note:
    __init__.py files for packages are autogenerated, and import all messages from submodules to keep import names consistent with the directory structure of the ``.proto`` source files.
"""
from .ioMappings_pb_plus import (
    IOMapping,
    IOMappingList,
    TopicInputMapping,
    TopicInputMappingList,
    TopicOutputMapping,
    TopicOutputMappingList,
)

from .session_pb_plus import (
    Session,
    SessionList,
    SessionStatus,
)


__all__ = (
    "IOMapping",
    "IOMappingList",
    "Session",
    "SessionList",
    "SessionStatus",
    "TopicInputMapping",
    "TopicInputMappingList",
    "TopicOutputMapping",
    "TopicOutputMappingList",
)


"""
@generated by codestare-proto-plus.  Do not edit manually!
"""
from proto import (
    Field,
    module,
)

from proto.message import (
    Message,
)

from ubii.proto.v1.dataStructure.handGestureType_pb_plus import (
    HandGestureType,
)

from ubii.proto.v1.dataStructure.quaternion_pb_plus import (
    Quaternion,
)

from ubii.proto.v1.dataStructure.vector3_pb_plus import (
    Vector3,
)

from ubii.proto.v1.dataStructure.vector8_pb_plus import (
    Vector8,
)


__protobuf__ = module(
    package="ubii.proto.v1.dataStructure",
    marshal="ubii.proto.v1",
    manifest={
        "MyoEvent",
    }
)


class MyoEvent(Message):
    """
    Attributes:
        emg (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.dataStructure.vector8_pb_plus.Vector8`
        orientation (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.dataStructure.quaternion_pb_plus.Quaternion`
        gyroscope (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.dataStructure.vector3_pb_plus.Vector3`
        accelerometer (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.dataStructure.vector3_pb_plus.Vector3`
        gesture (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.dataStructure.handGestureType_pb_plus.HandGestureType`
    """

    emg = Field(
        Vector8,
        number=1,
    )
    orientation = Field(
        Quaternion,
        number=2,
    )
    gyroscope = Field(
        Vector3,
        number=3,
    )
    accelerometer = Field(
        Vector3,
        number=4,
    )
    gesture = Field(
        HandGestureType,
        number=5,
    )




"""
@generated by codestare-proto-plus.  Do not edit manually!
"""
from proto import (
    Field,
    module,
)

from proto.message import (
    Message,
)

from ubii.proto.v1.clients.client_pb_plus import (
    Client,
    ClientList,
)

from ubii.proto.v1.dataStructure.lists_pb_plus import (
    StringList,
)

from ubii.proto.v1.devices.component_pb_plus import (
    Component,
    ComponentList,
)

from ubii.proto.v1.devices.device_pb_plus import (
    Device,
    DeviceList,
)

from ubii.proto.v1.devices.topicDemux_pb_plus import (
    TopicDemux,
    TopicDemuxList,
)

from ubii.proto.v1.devices.topicMux_pb_plus import (
    TopicMux,
    TopicMuxList,
)

from ubii.proto.v1.general.error_pb_plus import (
    Error,
)

from ubii.proto.v1.general.success_pb_plus import (
    Success,
)

from ubii.proto.v1.processing.lockstepProcessing_pb_plus import (
    LockstepProcessingReply,
)

from ubii.proto.v1.processing.processingModule_pb_plus import (
    ProcessingModule,
    ProcessingModuleList,
)

from ubii.proto.v1.servers.server_pb_plus import (
    Server,
)

from ubii.proto.v1.services.service_pb_plus import (
    Service,
    ServiceList,
)

from ubii.proto.v1.sessions.session_pb_plus import (
    Session,
    SessionList,
)


__protobuf__ = module(
    package="ubii.proto.v1.services",
    marshal="ubii.proto.v1",
    manifest={
        "ServiceReply",
    }
)


class ServiceReply(Message):
    """
    .. admonition:: One Ofs

        This message defines the following *oneof* group[s]

        .. attribute:: type

            - 	:attr:`.success`
            - 	:attr:`.error`
            - 	:attr:`.client`
            - 	:attr:`.device`
            - 	:attr:`.server`
            - 	:attr:`.session`
            - 	:attr:`.session_list`
            - 	:attr:`.processing_module`
            - 	:attr:`.processing_module_list`
            - 	:attr:`.string_list`
            - 	:attr:`.topic_mux`
            - 	:attr:`.topic_mux_list`
            - 	:attr:`.topic_demux`
            - 	:attr:`.topic_demux_list`
            - 	:attr:`.client_list`
            - 	:attr:`.device_list`
            - 	:attr:`.service`
            - 	:attr:`.service_list`
            - 	:attr:`.lockstep_processing_reply`
            - 	:attr:`.component`
            - 	:attr:`.component_list`

    Attributes:
        success (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.general.success_pb_plus.Success` -- *oneof* :attr:`.type`
        error (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.general.error_pb_plus.Error` -- *oneof* :attr:`.type`
        client (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.clients.client_pb_plus.Client` -- *oneof* :attr:`.type`
        device (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.devices.device_pb_plus.Device` -- *oneof* :attr:`.type`
        server (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.servers.server_pb_plus.Server` -- *oneof* :attr:`.type`
        session (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.sessions.session_pb_plus.Session` -- *oneof* :attr:`.type`
        session_list (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.sessions.session_pb_plus.SessionList` -- *oneof* :attr:`.type`
        processing_module (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.processing.processingModule_pb_plus.ProcessingModule` -- *oneof*
            :attr:`.type`
        processing_module_list (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.processing.processingModule_pb_plus.ProcessingModuleList` -- *oneof*
            :attr:`.type`
        string_list (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.dataStructure.lists_pb_plus.StringList` -- *oneof* :attr:`.type`
        topic_mux (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.devices.topicMux_pb_plus.TopicMux` -- *oneof* :attr:`.type`
        topic_mux_list (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.devices.topicMux_pb_plus.TopicMuxList` -- *oneof* :attr:`.type`
        topic_demux (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.devices.topicDemux_pb_plus.TopicDemux` -- *oneof* :attr:`.type`
        topic_demux_list (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.devices.topicDemux_pb_plus.TopicDemuxList` -- *oneof* :attr:`.type`
        client_list (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.clients.client_pb_plus.ClientList` -- *oneof* :attr:`.type`
        device_list (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.devices.device_pb_plus.DeviceList` -- *oneof* :attr:`.type`
        service (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.services.service_pb_plus.Service` -- *oneof* :attr:`.type`
        service_list (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.services.service_pb_plus.ServiceList` -- *oneof* :attr:`.type`
        lockstep_processing_reply (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.processing.lockstepProcessing_pb_plus.LockstepProcessingReply` -- *oneof*
            :attr:`.type`
        component (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.devices.component_pb_plus.Component` -- *oneof* :attr:`.type`
        component_list (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.devices.component_pb_plus.ComponentList` -- *oneof* :attr:`.type`
    """

    success = Field(
        Success,
        number=1,
        oneof='type',
    )
    error = Field(
        Error,
        number=2,
        oneof='type',
    )
    client = Field(
        Client,
        number=3,
        oneof='type',
    )
    device = Field(
        Device,
        number=4,
        oneof='type',
    )
    server = Field(
        Server,
        number=5,
        oneof='type',
    )
    session = Field(
        Session,
        number=6,
        oneof='type',
    )
    session_list = Field(
        SessionList,
        number=7,
        oneof='type',
    )
    processing_module = Field(
        ProcessingModule,
        number=8,
        oneof='type',
    )
    processing_module_list = Field(
        ProcessingModuleList,
        number=9,
        oneof='type',
    )
    string_list = Field(
        StringList,
        number=10,
        oneof='type',
    )
    topic_mux = Field(
        TopicMux,
        number=11,
        oneof='type',
    )
    topic_mux_list = Field(
        TopicMuxList,
        number=12,
        oneof='type',
    )
    topic_demux = Field(
        TopicDemux,
        number=13,
        oneof='type',
    )
    topic_demux_list = Field(
        TopicDemuxList,
        number=14,
        oneof='type',
    )
    client_list = Field(
        ClientList,
        number=15,
        oneof='type',
    )
    device_list = Field(
        DeviceList,
        number=16,
        oneof='type',
    )
    service = Field(
        Service,
        number=17,
        oneof='type',
    )
    service_list = Field(
        ServiceList,
        number=18,
        oneof='type',
    )
    lockstep_processing_reply = Field(
        LockstepProcessingReply,
        number=19,
        oneof='type',
    )
    component = Field(
        Component,
        number=20,
        oneof='type',
    )
    component_list = Field(
        ComponentList,
        number=21,
        oneof='type',
    )




"""
@generated by codestare-proto-plus.  Do not edit manually!
"""
from proto import (
    Field,
    RepeatedField,
    STRING,
    module,
)

from proto.message import (
    Message,
)


__protobuf__ = module(
    package="ubii.proto.v1.general",
    marshal="ubii.proto.v1",
    manifest={
        "Success",
        "SuccessList",
    }
)


class Success(Message):
    """
    Attributes:
        title (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.STRING`
        message (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.STRING`
    """

    title = Field(
        STRING,
        number=1,
    )
    message = Field(
        STRING,
        number=2,
    )


class SuccessList(Message):
    """
    Attributes:
        elements (proto.fields.RepeatedField): :obj:`~proto.fields.RepeatedField` of type
            :obj:`~.Success`
    """

    elements = RepeatedField(
        Success,
        number=1,
    )




"""
@generated by codestare-proto-plus.  Do not edit manually!
"""
from proto import (
    Field,
    RepeatedField,
    STRING,
    module,
)

from proto.message import (
    Message,
)


__protobuf__ = module(
    package="ubii.proto.v1.services",
    marshal="ubii.proto.v1",
    manifest={
        "Service",
        "ServiceList",
    }
)


class Service(Message):
    """
    Attributes:
        topic (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.STRING`
        request_message_format (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.STRING`
        response_message_format (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.STRING`
        tags (proto.fields.RepeatedField): :obj:`~proto.fields.RepeatedField` of type
            :obj:`~proto.primitives.ProtoType.STRING`
        description (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.STRING`
    """

    topic = Field(
        STRING,
        number=1,
    )
    request_message_format = Field(
        STRING,
        number=2,
    )
    response_message_format = Field(
        STRING,
        number=3,
    )
    tags = RepeatedField(
        STRING,
        number=4,
    )
    description = Field(
        STRING,
        number=5,
    )


class ServiceList(Message):
    """
    Attributes:
        elements (proto.fields.RepeatedField): :obj:`~proto.fields.RepeatedField` of type
            :obj:`~.Service`
    """

    elements = RepeatedField(
        Service,
        number=1,
    )




"""
@generated by codestare-proto-plus.  Do not edit manually!
"""
from proto import (
    BOOL,
    DOUBLE,
    FLOAT,
    Field,
    INT32,
    RepeatedField,
    STRING,
    module,
)

from proto.message import (
    Message,
)

from ubii.proto.v1.dataStructure.color_pb_plus import (
    Color,
)

from ubii.proto.v1.dataStructure.image_pb_plus import (
    Image2D,
    Image2DList,
)

from ubii.proto.v1.dataStructure.keyEvent_pb_plus import (
    KeyEvent,
)

from ubii.proto.v1.dataStructure.lists_pb_plus import (
    BoolList,
    DoubleList,
    FloatList,
    Int32List,
    StringList,
)

from ubii.proto.v1.dataStructure.matrix3x2_pb_plus import (
    Matrix3x2,
)

from ubii.proto.v1.dataStructure.matrix4x4_pb_plus import (
    Matrix4x4,
)

from ubii.proto.v1.dataStructure.mouseEvent_pb_plus import (
    MouseEvent,
)

from ubii.proto.v1.dataStructure.myoEvent_pb_plus import (
    MyoEvent,
)

from ubii.proto.v1.dataStructure.object2d_pb_plus import (
    Object2D,
    Object2DList,
)

from ubii.proto.v1.dataStructure.object3d_pb_plus import (
    Object3D,
    Object3DList,
)

from ubii.proto.v1.dataStructure.pose2d_pb_plus import (
    Pose2D,
)

from ubii.proto.v1.dataStructure.pose3d_pb_plus import (
    Pose3D,
)

from ubii.proto.v1.dataStructure.quaternion_pb_plus import (
    Quaternion,
)

from ubii.proto.v1.dataStructure.touchEvent_pb_plus import (
    TouchEvent,
    TouchEventList,
)

from ubii.proto.v1.dataStructure.vector2_pb_plus import (
    Vector2,
    Vector2List,
)

from ubii.proto.v1.dataStructure.vector3_pb_plus import (
    Vector3,
    Vector3List,
)

from ubii.proto.v1.dataStructure.vector4_pb_plus import (
    Vector4,
    Vector4List,
)

from ubii.proto.v1.sessions.session_pb_plus import (
    Session,
)

from ubii.proto.v1.topicData.timestamp_pb_plus import (
    Timestamp,
)


__protobuf__ = module(
    package="ubii.proto.v1.topicData",
    marshal="ubii.proto.v1",
    manifest={
        "TopicDataRecord",
        "TopicDataRecordList",
    }
)


class TopicDataRecord(Message):
    """
    continuous index: 38

    .. admonition:: One Ofs

        This message defines the following *oneof* group[s]

        .. attribute:: type

            - 	:attr:`.double`
            - 	:attr:`.bool`
            - 	:attr:`.string`
            - 	:attr:`.int32`
            - 	:attr:`.float`
            - 	:attr:`.vector2`
            - 	:attr:`.vector2_list`
            - 	:attr:`.vector3`
            - 	:attr:`.vector3_list`
            - 	:attr:`.vector4`
            - 	:attr:`.vector4_list`
            - 	:attr:`.quaternion`
            - 	:attr:`.quaternion_list`
            - 	:attr:`.matrix3x2`
            - 	:attr:`.matrix4x4`
            - 	:attr:`.color`
            - 	:attr:`.touch_event`
            - 	:attr:`.touch_event_list`
            - 	:attr:`.key_event`
            - 	:attr:`.mouse_event`
            - 	:attr:`.myo_event`
            - 	:attr:`.pose2D`
            - 	:attr:`.pose3D`
            - 	:attr:`.object2D`
            - 	:attr:`.object3D`
            - 	:attr:`.object2D_list`
            - 	:attr:`.object3D_list`
            - 	:attr:`.int32_list`
            - 	:attr:`.float_list`
            - 	:attr:`.double_list`
            - 	:attr:`.string_list`
            - 	:attr:`.bool_list`
            - 	:attr:`.image2D`
            - 	:attr:`.image2D_list`
            - 	:attr:`.session`

    Attributes:
        topic (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.STRING`
        timestamp (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.topicData.timestamp_pb_plus.Timestamp`
        client_id (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.STRING`
        double (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.DOUBLE` -- *oneof* :attr:`.type`
        bool (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.BOOL` -- *oneof* :attr:`.type`
        string (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.STRING` -- *oneof* :attr:`.type`
        int32 (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.INT32` -- *oneof* :attr:`.type`
        float (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.FLOAT` -- *oneof* :attr:`.type`
        vector2 (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.dataStructure.vector2_pb_plus.Vector2` -- *oneof* :attr:`.type`
        vector2_list (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.dataStructure.vector2_pb_plus.Vector2List` -- *oneof* :attr:`.type`
        vector3 (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.dataStructure.vector3_pb_plus.Vector3` -- *oneof* :attr:`.type`
        vector3_list (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.dataStructure.vector3_pb_plus.Vector3List` -- *oneof* :attr:`.type`
        vector4 (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.dataStructure.vector4_pb_plus.Vector4` -- *oneof* :attr:`.type`
        vector4_list (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.dataStructure.vector4_pb_plus.Vector4List` -- *oneof* :attr:`.type`
        quaternion (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.dataStructure.quaternion_pb_plus.Quaternion` -- *oneof*
            :attr:`.type`
        quaternion_list (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.dataStructure.quaternion_pb_plus.Quaternion` -- *oneof*
            :attr:`.type`
        matrix3x2 (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.dataStructure.matrix3x2_pb_plus.Matrix3x2` -- *oneof* :attr:`.type`
        matrix4x4 (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.dataStructure.matrix4x4_pb_plus.Matrix4x4` -- *oneof* :attr:`.type`
        color (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.dataStructure.color_pb_plus.Color` -- *oneof* :attr:`.type`
        touch_event (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.dataStructure.touchEvent_pb_plus.TouchEvent` -- *oneof*
            :attr:`.type`
        touch_event_list (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.dataStructure.touchEvent_pb_plus.TouchEventList` -- *oneof*
            :attr:`.type`
        key_event (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.dataStructure.keyEvent_pb_plus.KeyEvent` -- *oneof* :attr:`.type`
        mouse_event (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.dataStructure.mouseEvent_pb_plus.MouseEvent` -- *oneof*
            :attr:`.type`
        myo_event (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.dataStructure.myoEvent_pb_plus.MyoEvent` -- *oneof* :attr:`.type`
        pose2D (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.dataStructure.pose2d_pb_plus.Pose2D` -- *oneof* :attr:`.type`
        pose3D (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.dataStructure.pose3d_pb_plus.Pose3D` -- *oneof* :attr:`.type`
        object2D (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.dataStructure.object2d_pb_plus.Object2D` -- *oneof* :attr:`.type`
        object3D (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.dataStructure.object3d_pb_plus.Object3D` -- *oneof* :attr:`.type`
        object2D_list (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.dataStructure.object2d_pb_plus.Object2DList` -- *oneof*
            :attr:`.type`
        object3D_list (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.dataStructure.object3d_pb_plus.Object3DList` -- *oneof*
            :attr:`.type`
        int32_list (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.dataStructure.lists_pb_plus.Int32List` -- *oneof* :attr:`.type`
        float_list (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.dataStructure.lists_pb_plus.FloatList` -- *oneof* :attr:`.type`
        double_list (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.dataStructure.lists_pb_plus.DoubleList` -- *oneof* :attr:`.type`
        string_list (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.dataStructure.lists_pb_plus.StringList` -- *oneof* :attr:`.type`
        bool_list (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.dataStructure.lists_pb_plus.BoolList` -- *oneof* :attr:`.type`
        image2D (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.dataStructure.image_pb_plus.Image2D` -- *oneof* :attr:`.type`
        image2D_list (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.dataStructure.image_pb_plus.Image2DList` -- *oneof* :attr:`.type`
        session (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.sessions.session_pb_plus.Session` -- *oneof* :attr:`.type`
    """

    topic = Field(
        STRING,
        number=1,
    )
    timestamp = Field(
        Timestamp,
        number=2,
    )
    client_id = Field(
        STRING,
        number=33,
    )
    double = Field(
        DOUBLE,
        number=3,
        oneof='type',
    )
    bool = Field(
        BOOL,
        number=4,
        oneof='type',
    )
    string = Field(
        STRING,
        number=5,
        oneof='type',
    )
    int32 = Field(
        INT32,
        number=23,
        oneof='type',
    )
    float = Field(
        FLOAT,
        number=24,
        oneof='type',
    )
    vector2 = Field(
        Vector2,
        number=6,
        oneof='type',
    )
    vector2_list = Field(
        Vector2List,
        number=35,
        oneof='type',
    )
    vector3 = Field(
        Vector3,
        number=7,
        oneof='type',
    )
    vector3_list = Field(
        Vector3List,
        number=36,
        oneof='type',
    )
    vector4 = Field(
        Vector4,
        number=8,
        oneof='type',
    )
    vector4_list = Field(
        Vector4List,
        number=37,
        oneof='type',
    )
    quaternion = Field(
        Quaternion,
        number=9,
        oneof='type',
    )
    quaternion_list = Field(
        Quaternion,
        number=38,
        oneof='type',
    )
    matrix3x2 = Field(
        Matrix3x2,
        number=10,
        oneof='type',
    )
    matrix4x4 = Field(
        Matrix4x4,
        number=11,
        oneof='type',
    )
    color = Field(
        Color,
        number=12,
        oneof='type',
    )
    touch_event = Field(
        TouchEvent,
        number=13,
        oneof='type',
    )
    touch_event_list = Field(
        TouchEventList,
        number=34,
        oneof='type',
    )
    key_event = Field(
        KeyEvent,
        number=14,
        oneof='type',
    )
    mouse_event = Field(
        MouseEvent,
        number=15,
        oneof='type',
    )
    myo_event = Field(
        MyoEvent,
        number=16,
        oneof='type',
    )
    pose2D = Field(
        Pose2D,
        number=17,
        oneof='type',
    )
    pose3D = Field(
        Pose3D,
        number=18,
        oneof='type',
    )
    object2D = Field(
        Object2D,
        number=19,
        oneof='type',
    )
    object3D = Field(
        Object3D,
        number=20,
        oneof='type',
    )
    object2D_list = Field(
        Object2DList,
        number=21,
        oneof='type',
    )
    object3D_list = Field(
        Object3DList,
        number=22,
        oneof='type',
    )
    int32_list = Field(
        Int32List,
        number=25,
        oneof='type',
    )
    float_list = Field(
        FloatList,
        number=26,
        oneof='type',
    )
    double_list = Field(
        DoubleList,
        number=27,
        oneof='type',
    )
    string_list = Field(
        StringList,
        number=28,
        oneof='type',
    )
    bool_list = Field(
        BoolList,
        number=29,
        oneof='type',
    )
    image2D = Field(
        Image2D,
        number=30,
        oneof='type',
    )
    image2D_list = Field(
        Image2DList,
        number=31,
        oneof='type',
    )
    session = Field(
        Session,
        number=32,
        oneof='type',
    )


class TopicDataRecordList(Message):
    """
    Attributes:
        elements (proto.fields.RepeatedField): :obj:`~proto.fields.RepeatedField` of type
            :obj:`~.TopicDataRecord`
    """

    elements = RepeatedField(
        TopicDataRecord,
        number=1,
    )




"""
@generated by codestare-proto-plus.  Do not edit manually!
"""
from proto import (
    BYTES,
    Enum,
    Field,
    INT32,
    RepeatedField,
    module,
)

from proto.message import (
    Message,
)


__protobuf__ = module(
    package="ubii.proto.v1.dataStructure",
    marshal="ubii.proto.v1",
    manifest={
        "Image2D",
        "Image2DList",
    }
)


class Image2D(Message):
    """
    Attributes:
        width (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.INT32`
        height (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.INT32`
        data_format (proto.fields.Field): :obj:`~proto.fields.Field` of type :obj:`~.DataFormat`
        data (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.BYTES`
    """

    class DataFormat(Enum):
        GRAY8 = 0
        RGB8 = 1
        RGBA8 = 2

    width = Field(
        INT32,
        number=1,
    )
    height = Field(
        INT32,
        number=2,
    )
    data_format = Field(
        DataFormat,
        number=3,
    )
    data = Field(
        BYTES,
        number=4,
    )


class Image2DList(Message):
    """
    Attributes:
        elements (proto.fields.RepeatedField): :obj:`~proto.fields.RepeatedField` of type
            :obj:`~.Image2D`
    """

    elements = RepeatedField(
        Image2D,
        number=1,
    )




"""
@generated by codestare-proto-plus.  Do not edit manually!
"""
from proto import (
    BOOL,
    Enum,
    Field,
    INT32,
    RepeatedField,
    STRING,
    module,
)

from proto.message import (
    Message,
)


__protobuf__ = module(
    package="ubii.proto.v1.processing",
    marshal="ubii.proto.v1",
    manifest={
        "ProcessingMode",
        "ModuleIO",
        "ProcessingModule",
        "ProcessingModuleList",
    }
)


class ProcessingMode(Message):
    """
    .. admonition:: One Ofs

        This message defines the following *oneof* group[s]

        .. attribute:: mode

            - 	:attr:`.frequency`
            - 	:attr:`.lockstep`
            - 	:attr:`.trigger_on_input`
            - 	:attr:`.free`

    Attributes:
        frequency (proto.fields.Field): :obj:`~proto.fields.Field` of type :obj:`~.Frequency` -- *oneof*
            :attr:`.mode`
        lockstep (proto.fields.Field): :obj:`~proto.fields.Field` of type :obj:`~.Lockstep` -- *oneof*
            :attr:`.mode`
        trigger_on_input (proto.fields.Field): :obj:`~proto.fields.Field` of type :obj:`~.TriggerOnInput`
            -- *oneof* :attr:`.mode`
        free (proto.fields.Field): :obj:`~proto.fields.Field` of type :obj:`~.Free` -- *oneof*
            :attr:`.mode`
    """

    class Frequency(Message):
        """
        Processing Callback is executed at a fixed time interval, with target frequency

        Attributes:
            hertz (proto.fields.Field): :obj:`~proto.fields.Field` of type
                :obj:`~proto.primitives.ProtoType.INT32`
        """

        hertz = Field(
            INT32,
            number=1,
        )
    

    class Lockstep(Message):
        """
        Processing Callback is executed when the master node sends a lockstep processing request

        Attributes:
            process_request_endpoint (proto.fields.Field): :obj:`~proto.fields.Field` of type
                :obj:`~proto.primitives.ProtoType.STRING`
        """

        process_request_endpoint = Field(
            STRING,
            number=1,
        )
    

    class TriggerOnInput(Message):
        """
        Processing Callback is executed when all or any of the input data changes

        Attributes:
            min_delay_ms (proto.fields.Field): :obj:`~proto.fields.Field` of type
                :obj:`~proto.primitives.ProtoType.INT32`
            all_inputs_need_update (proto.fields.Field): :obj:`~proto.fields.Field` of type
                :obj:`~proto.primitives.ProtoType.BOOL`
        """

        min_delay_ms = Field(
            INT32,
            number=1,
        )
        all_inputs_need_update = Field(
            BOOL,
            number=2,
        )
    

    class Free(Message):
        """"""

    

    frequency = Field(
        Frequency,
        number=1,
        oneof='mode',
    )
    lockstep = Field(
        Lockstep,
        number=2,
        oneof='mode',
    )
    trigger_on_input = Field(
        TriggerOnInput,
        number=3,
        oneof='mode',
    )
    free = Field(
        Free,
        number=4,
        oneof='mode',
    )


class ModuleIO(Message):
    """
    Attributes:
        internal_name (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.STRING`
        message_format (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.STRING`
        is_record_list (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.BOOL`
    """

    internal_name = Field(
        STRING,
        number=1,
    )
    message_format = Field(
        STRING,
        number=2,
    )
    is_record_list = Field(
        BOOL,
        number=3,
    )


class ProcessingModule(Message):
    """
    Attributes:
        id (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.STRING`
        name (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.STRING`
        authors (proto.fields.RepeatedField): :obj:`~proto.fields.RepeatedField` of type
            :obj:`~proto.primitives.ProtoType.STRING`
        tags (proto.fields.RepeatedField): :obj:`~proto.fields.RepeatedField` of type
            :obj:`~proto.primitives.ProtoType.STRING`
        description (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.STRING`
        node_id (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.STRING`
        session_id (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.STRING`
        status (proto.fields.Field): :obj:`~proto.fields.Field` of type :obj:`~.Status`
        processing_mode (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~.ProcessingMode`
        inputs (proto.fields.RepeatedField): :obj:`~proto.fields.RepeatedField` of type
            :obj:`~.ModuleIO`
        outputs (proto.fields.RepeatedField): :obj:`~proto.fields.RepeatedField` of type
            :obj:`~.ModuleIO`
        language (proto.fields.Field): :obj:`~proto.fields.Field` of type :obj:`~.Language`
        on_processing_stringified (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.STRING`
        on_created_stringified (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.STRING`
        on_halted_stringified (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.STRING`
        on_destroyed_stringified (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.STRING`
    """

    class Status(Enum):
        INITIALIZED = 0
        CREATED = 1
        PROCESSING = 2
        HALTED = 3
        DESTROYED = 4

    class Language(Enum):
        CPP = 0
        PY = 1
        JS = 2
        CS = 3
        JAVA = 4

    id = Field(
        STRING,
        number=1,
    )
    name = Field(
        STRING,
        number=2,
    )
    authors = RepeatedField(
        STRING,
        number=3,
    )
    tags = RepeatedField(
        STRING,
        number=4,
    )
    description = Field(
        STRING,
        number=5,
    )
    node_id = Field(
        STRING,
        number=6,
    )
    session_id = Field(
        STRING,
        number=7,
    )
    status = Field(
        Status,
        number=8,
    )
    processing_mode = Field(
        ProcessingMode,
        number=9,
    )
    inputs = RepeatedField(
        ModuleIO,
        number=10,
    )
    outputs = RepeatedField(
        ModuleIO,
        number=11,
    )
    language = Field(
        Language,
        number=12,
    )
    on_processing_stringified = Field(
        STRING,
        number=13,
    )
    on_created_stringified = Field(
        STRING,
        number=14,
    )
    on_halted_stringified = Field(
        STRING,
        number=15,
    )
    on_destroyed_stringified = Field(
        STRING,
        number=16,
    )


class ProcessingModuleList(Message):
    """
    Attributes:
        elements (proto.fields.RepeatedField): :obj:`~proto.fields.RepeatedField` of type
            :obj:`~.ProcessingModule`
    """

    elements = RepeatedField(
        ProcessingModule,
        number=1,
    )




"""
@generated by codestare-proto-plus.  Do not edit manually!
"""
from proto import (
    Field,
    INT32,
    INT64,
    module,
)

from proto.message import (
    Message,
)


__protobuf__ = module(
    package="ubii.proto.v1.topicData",
    marshal="ubii.proto.v1",
    manifest={
        "Timestamp",
    }
)


class Timestamp(Message):
    """
    Attributes:
        seconds (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.INT64`
        nanos (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.INT32`
        millis (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.INT64`
    """

    seconds = Field(
        INT64,
        number=1,
    )
    nanos = Field(
        INT32,
        number=2,
    )
    millis = Field(
        INT64,
        number=3,
    )




"""
@generated by codestare-proto-plus.  Do not edit manually!
"""
from proto import (
    BOOL,
    Enum,
    Field,
    RepeatedField,
    STRING,
    module,
)

from proto.message import (
    Message,
)

from ubii.proto.v1.processing.processingModule_pb_plus import (
    ProcessingModule,
)

from ubii.proto.v1.sessions.ioMappings_pb_plus import (
    IOMapping,
)


__protobuf__ = module(
    package="ubii.proto.v1.sessions",
    marshal="ubii.proto.v1",
    manifest={
        "Session",
        "SessionList",
        "SessionStatus",
    }
)


class SessionStatus(Enum):
    CREATED = 0
    RUNNING = 1
    PAUSED = 2
    STOPPED = 3

class Session(Message):
    """
    Attributes:
        id (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.STRING`
        name (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.STRING`
        processing_modules (proto.fields.RepeatedField): :obj:`~proto.fields.RepeatedField` of type
            :obj:`~ubii.proto.v1.processing.processingModule_pb_plus.ProcessingModule`
        io_mappings (proto.fields.RepeatedField): :obj:`~proto.fields.RepeatedField` of type
            :obj:`~ubii.proto.v1.sessions.ioMappings_pb_plus.IOMapping`
        tags (proto.fields.RepeatedField): :obj:`~proto.fields.RepeatedField` of type
            :obj:`~proto.primitives.ProtoType.STRING`
        description (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.STRING`
        authors (proto.fields.RepeatedField): :obj:`~proto.fields.RepeatedField` of type
            :obj:`~proto.primitives.ProtoType.STRING`
        status (proto.fields.Field): :obj:`~proto.fields.Field` of type :obj:`~.SessionStatus`
        editable (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.BOOL`
    """

    id = Field(
        STRING,
        number=1,
    )
    name = Field(
        STRING,
        number=2,
    )
    processing_modules = RepeatedField(
        ProcessingModule,
        number=3,
    )
    io_mappings = RepeatedField(
        IOMapping,
        number=4,
    )
    tags = RepeatedField(
        STRING,
        number=5,
    )
    description = Field(
        STRING,
        number=6,
    )
    authors = RepeatedField(
        STRING,
        number=7,
    )
    status = Field(
        SessionStatus,
        number=8,
    )
    editable = Field(
        BOOL,
        number=9,
    )


class SessionList(Message):
    """
    Attributes:
        elements (proto.fields.RepeatedField): :obj:`~proto.fields.RepeatedField` of type
            :obj:`~.Session`
    """

    elements = RepeatedField(
        Session,
        number=1,
    )




"""
@generated by codestare-proto-plus.  Do not edit manually!
"""
from proto import (
    DOUBLE,
    Field,
    RepeatedField,
    module,
)

from proto.message import (
    Message,
)


__protobuf__ = module(
    package="ubii.proto.v1.dataStructure",
    marshal="ubii.proto.v1",
    manifest={
        "Quaternion",
        "QuaternionList",
    }
)


class Quaternion(Message):
    """
    Attributes:
        x (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.DOUBLE`
        y (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.DOUBLE`
        z (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.DOUBLE`
        w (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.DOUBLE`
    """

    x = Field(
        DOUBLE,
        number=1,
    )
    y = Field(
        DOUBLE,
        number=2,
    )
    z = Field(
        DOUBLE,
        number=3,
    )
    w = Field(
        DOUBLE,
        number=4,
    )


class QuaternionList(Message):
    """
    Attributes:
        elements (proto.fields.RepeatedField): :obj:`~proto.fields.RepeatedField` of type
            :obj:`~.Quaternion`
    """

    elements = RepeatedField(
        Quaternion,
        number=1,
    )




"""
@generated by codestare-proto-plus.  Do not edit manually!
"""
from proto import (
    Field,
    STRING,
    module,
)

from proto.message import (
    Message,
)


__protobuf__ = module(
    package="ubii.proto.v1.servers",
    marshal="ubii.proto.v1",
    manifest={
        "Server",
    }
)


class Server(Message):
    """
    Attributes:
        id (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.STRING`
        name (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.STRING`
        ip_ethernet (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.STRING`
        ip_wlan (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.STRING`
        port_service_zmq (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.STRING`
        port_service_rest (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.STRING`
        port_topic_data_zmq (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.STRING`
        port_topic_data_ws (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.STRING`
        constants_json (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.STRING`
        external_address_service_zmq (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.STRING`
        external_address_service_http_json (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.STRING`
        external_address_service_http_binary (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.STRING`
        external_address_topic_data_zmq (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.STRING`
        external_address_topic_data_ws (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.STRING`
    """

    id = Field(
        STRING,
        number=1,
    )
    name = Field(
        STRING,
        number=2,
    )
    ip_ethernet = Field(
        STRING,
        number=3,
    )
    ip_wlan = Field(
        STRING,
        number=4,
    )
    port_service_zmq = Field(
        STRING,
        number=5,
    )
    port_service_rest = Field(
        STRING,
        number=6,
    )
    port_topic_data_zmq = Field(
        STRING,
        number=7,
    )
    port_topic_data_ws = Field(
        STRING,
        number=8,
    )
    constants_json = Field(
        STRING,
        number=9,
    )
    external_address_service_zmq = Field(
        STRING,
        number=10,
    )
    external_address_service_http_json = Field(
        STRING,
        number=11,
    )
    external_address_service_http_binary = Field(
        STRING,
        number=12,
    )
    external_address_topic_data_zmq = Field(
        STRING,
        number=13,
    )
    external_address_topic_data_ws = Field(
        STRING,
        number=14,
    )




"""
@generated by codestare-proto-plus.  Do not edit manually!
"""
from proto import (
    Field,
    RepeatedField,
    STRING,
    module,
)

from proto.message import (
    Message,
)

from ubii.proto.v1.dataStructure.pose2d_pb_plus import (
    Pose2D,
)

from ubii.proto.v1.dataStructure.vector2_pb_plus import (
    Vector2,
)


__protobuf__ = module(
    package="ubii.proto.v1.dataStructure",
    marshal="ubii.proto.v1",
    manifest={
        "Object2D",
        "Object2DList",
    }
)


class Object2D(Message):
    """
    Attributes:
        id (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.STRING`
        pose (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.dataStructure.pose2d_pb_plus.Pose2D`
        size (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.dataStructure.vector2_pb_plus.Vector2`
        user_data_json (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.STRING`
    """

    id = Field(
        STRING,
        number=1,
    )
    pose = Field(
        Pose2D,
        number=2,
    )
    size = Field(
        Vector2,
        number=3,
    )
    user_data_json = Field(
        STRING,
        number=4,
    )


class Object2DList(Message):
    """
    Attributes:
        elements (proto.fields.RepeatedField): :obj:`~proto.fields.RepeatedField` of type
            :obj:`~.Object2D`
    """

    elements = RepeatedField(
        Object2D,
        number=1,
    )




"""
@generated by codestare-proto-plus.  Do not edit manually!

Note:
    __init__.py files for packages are autogenerated, and import all messages from submodules to keep import names consistent with the directory structure of the ``.proto`` source files.
"""
from .timestamp_pb_plus import (
    Timestamp,
)

from .topicDataRecord_pb_plus import (
    TopicDataRecord,
    TopicDataRecordList,
)

from .topicData_pb_plus import (
    TopicData,
)


__all__ = (
    "Timestamp",
    "TopicData",
    "TopicDataRecord",
    "TopicDataRecordList",
)


"""
@generated by codestare-proto-plus.  Do not edit manually!
"""
from proto import (
    Enum,
    FLOAT,
    Field,
    RepeatedField,
    STRING,
    module,
)

from proto.message import (
    Message,
)

from ubii.proto.v1.dataStructure.vector2_pb_plus import (
    Vector2,
)


__protobuf__ = module(
    package="ubii.proto.v1.dataStructure",
    marshal="ubii.proto.v1",
    manifest={
        "TouchEvent",
        "TouchEventList",
    }
)


class TouchEvent(Message):
    """
    Attributes:
        type (proto.fields.Field): :obj:`~proto.fields.Field` of type :obj:`~.TouchEventType`
        position (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.dataStructure.vector2_pb_plus.Vector2`
        id (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.STRING`
        force (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.FLOAT`
    """

    class TouchEventType(Enum):
        TOUCH_START = 0
        TOUCH_MOVE = 1
        TOUCH_END = 2

    type = Field(
        TouchEventType,
        number=1,
    )
    position = Field(
        Vector2,
        number=2,
    )
    id = Field(
        STRING,
        number=3,
    )
    force = Field(
        FLOAT,
        number=4,
    )


class TouchEventList(Message):
    """
    Attributes:
        elements (proto.fields.RepeatedField): :obj:`~proto.fields.RepeatedField` of type
            :obj:`~.TouchEvent`
    """

    elements = RepeatedField(
        TouchEvent,
        number=1,
    )




"""
@generated by codestare-proto-plus.  Do not edit manually!

Note:
    __init__.py files for packages are autogenerated, and import all messages from submodules to keep import names consistent with the directory structure of the ``.proto`` source files.
"""
from .error_pb_plus import (
    Error,
    ErrorList,
)

from .success_pb_plus import (
    Success,
    SuccessList,
)


__all__ = (
    "Error",
    "ErrorList",
    "Success",
    "SuccessList",
)


"""
Utility features to format protobuf messages and implement protobuf wrapper classes with custom behaviour.

Attributes:
    __imported_types__ (dict): module level dictionary caching imported types
"""

import collections
import functools
import importlib
import itertools
import json
import logging
import re
import warnings
import weakref
from abc import ABCMeta
from typing import Dict, Iterable

import google.protobuf.json_format
import google.protobuf.message
import proto.message

log = logging.getLogger(__name__)
__imported_types__ = {}

import_name = collections.namedtuple('import_name', ['package', 'type'])


def get_import_name(message_type: str):
    """
    The .proto files declare a package name 'ubii', but this is not reflected in the python package.
    Instead the package is named ubii.proto, to not clash with different packages in the ubii namespace.
    The python files are generated from updated proto files, to produce the correct directory structure.
    The directory structure determines python package names see
    https://developers.google.com/protocol-buffers/docs/reference/python-generated#package

    Args:
        message_type (str): string describing the data type

    """

    if not message_type.startswith('ubii.'):
        raise ValueError(f"{message_type} does not seem to be a special ubi-interact message type.")

    from . import __proto_module__
    package, typ = message_type.replace(
        'ubii', __proto_module__
    ).rsplit('.', maxsplit=1)

    return import_name(package=package, type=typ)


def import_type(message_type: str, reimport=False):
    """
    See the documentation of the ubii-msg-compiler at https://github.com/saggitar/ubii-msg-compiler
    for more information about updating the .proto files to generate a different package structure.

    Args:
        message_type (str): string describing the data type
        reimport (bool): If true force reimport of type

    """

    def _import(name: str) -> proto.Message:
        package, type_ = get_import_name(name)
        package = importlib.import_module(package)
        type_ = getattr(package, type_, None)

        if type_ is None:
            raise ValueError(f"{name} could not be imported.")
        return type_

    if message_type not in __imported_types__ or reimport:
        __imported_types__[message_type] = _import(message_type)

    return __imported_types__[message_type]


def clean_json(message: str):
    r"""
    Format json strings (like representations of proto messages) in a nice way.
    Close to ``re.sub(r'{\s+', '{', message.strip())``

    Returns:
        str: cleaned string
    """
    cleaned = message.strip()
    formatted = re.sub(r'{\s+', '{', cleaned)
    formatted = re.sub(r'\s', '', formatted)
    return formatted


def patch_wrapper_class_repr(replacement='...', max_len=50) -> None:
    """
    E.g. for documentation purposes it's undesirable that the `__repr__` method of
    :class:`proto.message.Message` simply returns formatted json for the message object.
    For messages with many fields or long representation of field values this to much information.

    This function simply monkeypatches the `__repr__` method of :class:`proto.message.Message` to replace
    output that is longer than :param:`max_len` with :param:`replacement`

    Args:
        replacement: string used as replacement
        max_len: shorter representations will not be converted

    """

    def patch(__repr__):
        @functools.wraps(__repr__)
        def wrapped(self):
            type_ = self.__class__
            pb_type_descr = type_.pb().DESCRIPTOR
            vars_ = {name: getattr(self, name) for name in pb_type_descr.fields_by_name}

            def short_repr(value, max_len=max_len):
                orig = clean_json(str(value)) if isinstance(value, proto.Message) else repr(value)
                if len(orig) < max_len:
                    return orig
                else:
                    return replacement

            formatted = ', '.join('{}={}'.format(name, short_repr(value)) for name, value in vars_.items() if value)
            return f"{type_.__name__}(" + (formatted if len(formatted) < max_len else replacement) + ")"

            # return f"{name}({clean_json(old_repr)})"

        return wrapped

    proto.Message.__repr__ = patch(proto.Message.__repr__)


class ProtoEncoder(json.JSONEncoder):
    """
    Custom encoder to convert Protobuf Messages and Proto-Plus Messages to valid json.
    """

    #: dictionary of default arguments passed to the :meth:`proto.message.Message.to_dict` or
    #: :func:`google.protobuf.json_format.MessageToDict` calls which are used to convert the message object.
    format_options: Dict[str, bool] = {
        "use_integers_for_enums": True,
        "including_default_value_fields": True,
        "preserving_proto_field_name": False,
    }

    def default(self, o):
        """
        returns a serializable object for ``o``, or calls the base implementation (to raise a ``TypeError``).

        Args:
            o (object): (hopefully) serializable object, e.g. Protobuf message

        Returns:
            dict: Dictionary representation of message using :meth:`proto.message.Message.to_dict` or
            :func:`google.protobuf.json_format.MessageToDict`

        Raises:
            TypeError: If object is not serializable as Protobuf Message of by :meth:`json.JSONEncoder.default`

        """
        if isinstance(o, proto.Message):
            return type(o).to_dict(o, **self.format_options)

        if isinstance(o, google.protobuf.message.Message):
            return google.protobuf.json_format.MessageToDict(o, **self.format_options)

        return json.JSONEncoder.default(self, o)


class ProtoMeta(ABCMeta, proto.message.MessageMeta):
    """
    This metaclass is used to inherit from :doc:`plus:index` wrapper classes

    Example:
        Make sure you import and set :mod:`ubii.proto.__protobuf__` in every module
        which defines new :class:`~proto.message.Message` types::

            import ubii.proto as ub
            __protobuf__ = ub.__protobuf__

            class Fancy(ub.Component, metaclass=ub.ProtoMeta):
                @property
                def something_amazing(self)
                    return "Wow"

    """
    __additional_attributes = weakref.WeakKeyDictionary()

    # used for docstring processing, will be refactored into own class at some point
    _starting_indent = re.compile(r'^( +)', re.MULTILINE)
    _attributes_section = re.compile(r'^(( *)Attributes:.*)', re.DOTALL | re.MULTILINE)
    _field = re.compile(r'^\s*(\w+) ?.*:')

    def _fix_docstring(cls, parent):
        if not cls.__doc__:
            warnings.warn(f"Missing docstring for {cls}")
            return cls

        def get_attributes_section(kls):
            sections = cls._attributes_section.findall(kls.__doc__)
            assert len(sections) <= 1, f"{len(sections)} 'Attributes:' sections found in {kls}"
            return sections[0] if sections else ('', cls._starting_indent.findall(kls.__doc__)[0])

        def make_attrs_dict(lines):
            attributes = {}
            name = None

            for line in (lines.split('\n')[1:] if lines else []):
                field = cls._field.match(line)
                if field:
                    name = field.groups()[0]
                    attributes[name] = [line]
                else:
                    attributes[name] += [line]

            return attributes

        parent_section, parent_indent = get_attributes_section(parent)
        parent_attributes = make_attrs_dict(parent_section)

        this_section, this_indent = get_attributes_section(cls)
        this_attributes = make_attrs_dict(this_section)
        fix_indent = functools.partial(re.sub, f"^{parent_indent}", this_indent, flags=re.MULTILINE)

        for key, lines in parent_attributes.items():
            if key in this_attributes:
                continue

            this_attributes[key] = [fix_indent(line) for line in lines if line.strip()]

            indent, = cls._starting_indent.findall(this_attributes[key][-1])  # indent of last line

            if len(lines) == 1:
                indent += ''.join([' '] * 4)

            # append line with info
            this_attributes[key] += [f"{indent}-- inherited from :class:`~{parent.__module__}.{parent.__qualname__}`"]

        values = list(itertools.chain.from_iterable(this_attributes.values()))
        doc = cls.__doc__
        attr_loc = doc.index(this_section) if this_section else len(doc)
        prev, after = doc[:attr_loc], doc[attr_loc + len(this_section) + 1:]  # parts before and after section

        # insert new section in place of old
        cls.__doc__ = (
                fix_indent(prev) +
                '\n' +
                '\n'.join(itertools.chain(map(fix_indent, parent_section.split('\n')[:1]), values)) +
                fix_indent(after)
        )

        return cls

    def __new__(mcs, name, bases, attrs):
        message_bases = [b for b in bases if isinstance(b, proto.message.MessageMeta)]
        if len(message_bases) != 1:
            raise NotImplemented(f"Can't subclass with {len(message_bases)} Message parent classes")

        parent: proto.message.MessageMeta = message_bases[0]
        cls = super().__new__(mcs, name, bases, {**attrs, **parent.meta.fields})
        cls.meta._pb = parent.pb()

        assert cls not in mcs.__additional_attributes
        mcs.__additional_attributes[cls] = attrs

        cls = cls._fix_docstring(parent)
        return cls

    def __dir__(cls) -> Iterable[str]:
        names = set(proto.message.MessageMeta.__dir__(cls))
        attributes = cls.__additional_attributes.get(cls, {})
        names.update(set(attributes))
        return names


__all__ = (
    "get_import_name",
    "import_type",
    "ProtoMeta",
    "ProtoEncoder",
    "patch_wrapper_class_repr"
)



"""
@generated by codestare-proto-plus.  Do not edit manually!
"""
from proto import (
    FLOAT,
    Field,
    module,
)

from proto.message import (
    Message,
)

from ubii.proto.v1.dataStructure.vector2_pb_plus import (
    Vector2,
)


__protobuf__ = module(
    package="ubii.proto.v1.dataStructure",
    marshal="ubii.proto.v1",
    manifest={
        "Pose2D",
    }
)


class Pose2D(Message):
    """
    .. admonition:: One Ofs

        This message defines the following *oneof* group[s]

        .. attribute:: orientation

            - 	:attr:`.direction`
            - 	:attr:`.angle`

    Attributes:
        position (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.dataStructure.vector2_pb_plus.Vector2`
        direction (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.dataStructure.vector2_pb_plus.Vector2` -- *oneof*
            :attr:`.orientation`
        angle (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.FLOAT` -- *oneof* :attr:`.orientation`
    """

    position = Field(
        Vector2,
        number=1,
    )
    direction = Field(
        Vector2,
        number=2,
        oneof='orientation',
    )
    angle = Field(
        FLOAT,
        number=3,
        oneof='orientation',
    )




"""
@generated by codestare-proto-plus.  Do not edit manually!
"""
from proto import (
    Field,
    module,
)

from proto.message import (
    Message,
)

from ubii.proto.v1.dataStructure.quaternion_pb_plus import (
    Quaternion,
)

from ubii.proto.v1.dataStructure.vector3_pb_plus import (
    Vector3,
)


__protobuf__ = module(
    package="ubii.proto.v1.dataStructure",
    marshal="ubii.proto.v1",
    manifest={
        "Pose3D",
    }
)


class Pose3D(Message):
    """
    .. admonition:: One Ofs

        This message defines the following *oneof* group[s]

        .. attribute:: orientation

            - 	:attr:`.quaternion`
            - 	:attr:`.euler`

    Attributes:
        position (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.dataStructure.vector3_pb_plus.Vector3`
        quaternion (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.dataStructure.quaternion_pb_plus.Quaternion` -- *oneof*
            :attr:`.orientation`
        euler (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.dataStructure.vector3_pb_plus.Vector3` -- *oneof*
            :attr:`.orientation`
    """

    position = Field(
        Vector3,
        number=1,
    )
    quaternion = Field(
        Quaternion,
        number=2,
        oneof='orientation',
    )
    euler = Field(
        Vector3,
        number=3,
        oneof='orientation',
    )




"""
@generated by codestare-proto-plus.  Do not edit manually!
"""
from proto import (
    Field,
    STRING,
    module,
)

from proto.message import (
    Message,
)

from ubii.proto.v1.clients.client_pb_plus import (
    Client,
    ClientList,
)

from ubii.proto.v1.devices.component_pb_plus import (
    Component,
    ComponentList,
)

from ubii.proto.v1.devices.device_pb_plus import (
    Device,
    DeviceList,
)

from ubii.proto.v1.devices.topicDemux_pb_plus import (
    TopicDemux,
    TopicDemuxList,
)

from ubii.proto.v1.devices.topicMux_pb_plus import (
    TopicMux,
    TopicMuxList,
)

from ubii.proto.v1.processing.lockstepProcessing_pb_plus import (
    LockstepProcessingRequest,
)

from ubii.proto.v1.processing.processingModule_pb_plus import (
    ProcessingModule,
    ProcessingModuleList,
)

from ubii.proto.v1.services.request.topicSubscription_pb_plus import (
    TopicSubscription,
)

from ubii.proto.v1.sessions.session_pb_plus import (
    Session,
    SessionList,
)


__protobuf__ = module(
    package="ubii.proto.v1.services",
    marshal="ubii.proto.v1",
    manifest={
        "ServiceRequest",
    }
)


class ServiceRequest(Message):
    """
    .. admonition:: One Ofs

        This message defines the following *oneof* group[s]

        .. attribute:: type

            - 	:attr:`.client`
            - 	:attr:`.device`
            - 	:attr:`.topic_subscription`
            - 	:attr:`.session`
            - 	:attr:`.session_list`
            - 	:attr:`.processing_module`
            - 	:attr:`.processing_module_list`
            - 	:attr:`.topic_mux`
            - 	:attr:`.topic_mux_list`
            - 	:attr:`.topic_demux`
            - 	:attr:`.topic_demux_list`
            - 	:attr:`.client_list`
            - 	:attr:`.device_list`
            - 	:attr:`.lockstep_processing_request`
            - 	:attr:`.component`
            - 	:attr:`.component_list`

    Attributes:
        topic (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.primitives.ProtoType.STRING`
        client (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.clients.client_pb_plus.Client` -- *oneof* :attr:`.type`
        device (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.devices.device_pb_plus.Device` -- *oneof* :attr:`.type`
        topic_subscription (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.services.request.topicSubscription_pb_plus.TopicSubscription` -- *oneof*
            :attr:`.type`
        session (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.sessions.session_pb_plus.Session` -- *oneof* :attr:`.type`
        session_list (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.sessions.session_pb_plus.SessionList` -- *oneof* :attr:`.type`
        processing_module (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.processing.processingModule_pb_plus.ProcessingModule` -- *oneof*
            :attr:`.type`
        processing_module_list (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.processing.processingModule_pb_plus.ProcessingModuleList` -- *oneof*
            :attr:`.type`
        topic_mux (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.devices.topicMux_pb_plus.TopicMux` -- *oneof* :attr:`.type`
        topic_mux_list (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.devices.topicMux_pb_plus.TopicMuxList` -- *oneof* :attr:`.type`
        topic_demux (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.devices.topicDemux_pb_plus.TopicDemux` -- *oneof* :attr:`.type`
        topic_demux_list (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.devices.topicDemux_pb_plus.TopicDemuxList` -- *oneof* :attr:`.type`
        client_list (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.clients.client_pb_plus.ClientList` -- *oneof* :attr:`.type`
        device_list (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.devices.device_pb_plus.DeviceList` -- *oneof* :attr:`.type`
        lockstep_processing_request (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.processing.lockstepProcessing_pb_plus.LockstepProcessingRequest` --
            *oneof* :attr:`.type`
        component (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.devices.component_pb_plus.Component` -- *oneof* :attr:`.type`
        component_list (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~ubii.proto.v1.devices.component_pb_plus.ComponentList` -- *oneof* :attr:`.type`
    """

    topic = Field(
        STRING,
        number=1,
    )
    client = Field(
        Client,
        number=2,
        oneof='type',
    )
    device = Field(
        Device,
        number=3,
        oneof='type',
    )
    topic_subscription = Field(
        TopicSubscription,
        number=4,
        oneof='type',
    )
    session = Field(
        Session,
        number=5,
        oneof='type',
    )
    session_list = Field(
        SessionList,
        number=6,
        oneof='type',
    )
    processing_module = Field(
        ProcessingModule,
        number=7,
        oneof='type',
    )
    processing_module_list = Field(
        ProcessingModuleList,
        number=8,
        oneof='type',
    )
    topic_mux = Field(
        TopicMux,
        number=9,
        oneof='type',
    )
    topic_mux_list = Field(
        TopicMuxList,
        number=10,
        oneof='type',
    )
    topic_demux = Field(
        TopicDemux,
        number=11,
        oneof='type',
    )
    topic_demux_list = Field(
        TopicDemuxList,
        number=12,
        oneof='type',
    )
    client_list = Field(
        ClientList,
        number=13,
        oneof='type',
    )
    device_list = Field(
        DeviceList,
        number=14,
        oneof='type',
    )
    lockstep_processing_request = Field(
        LockstepProcessingRequest,
        number=15,
        oneof='type',
    )
    component = Field(
        Component,
        number=16,
        oneof='type',
    )
    component_list = Field(
        ComponentList,
        number=17,
        oneof='type',
    )




"""
@generated by codestare-proto-plus.  Do not edit manually!

Note:
    __init__.py files for packages are autogenerated, and import all messages from submodules to keep import names consistent with the directory structure of the ``.proto`` source files.
"""
from .component_pb_plus import (
    Component,
    ComponentList,
)

from .device_pb_plus import (
    Device,
    DeviceList,
)

from .topicDemux_pb_plus import (
    TopicDemux,
    TopicDemuxList,
)

from .topicMux_pb_plus import (
    TopicMux,
    TopicMuxList,
)


__all__ = (
    "Component",
    "ComponentList",
    "Device",
    "DeviceList",
    "TopicDemux",
    "TopicDemuxList",
    "TopicMux",
    "TopicMuxList",
)